@@ -21,7 +21,10 @@ class DocumentViewSet(mixins.CreateModelMixin, mixins.DestroyModelMixin, mixins.
 
 
 class DocumentTypeViewSet(mixins.CreateModelMixin, mixins.DestroyModelMixin, mixins.ListModelMixin,
-                          viewsets.GenericViewSet):
+                          mixins.UpdateModelMixin, viewsets.GenericViewSet):
     permission_classes = (DjangoModelPermissions, )
     queryset = services.get_document_types()
     serializer_class = serializer.DocumentTypeSerializer
+
+    def perform_destroy(self, document_type):
+        services.delete_document_type(document_type)
